module I2S_tx (
  input wire mclk,            // Master Clock
  input wire nReset,          // Reset input
  input wire [23:0] audio_input, // 24-bit Audio Input
  output wire sclk,           // System Clock
  output wire lrclk,          // Left/Right Clock
  output wire sdata           // Audio Data
);

  reg [23:0] audio_data;       // 24-bit Audio Data Register
  reg [5:0] lrclk_divider;     // Left/Right Clock Divider (6 bits for 64 states)

  always @(posedge mclk or posedge nReset) begin
    if (nReset) begin
      audio_data <= 0;
      lrclk_divider <= 0;
    end else begin
      // Shift in new audio data on rising edge of master clock
      audio_data <= audio_input;

      // Increment Left/Right Clock Divider on rising edge of master clock
      if (lrclk_divider == 6'b111111) begin
        lrclk_divider <= 0;
      end else begin
        lrclk_divider <= lrclk_divider + 1;
      end
    end
  end

  // Generate System Clock (sclk)
  assign sclk = mclk;

  // Generate Left/Right Clock (lrclk)
  assign lrclk = lrclk_divider[5]; // LRCLK switches state every 32 clock cycles (64 states)

  // Output Audio Data (sdata) directly
  assign sdata = audio_data;

endmodule

